\encoding{Windows-1250}
\name{DebonQB}
\title{Q vs. B diagram (Debon + Le Fort 1983)}
\alias{DebonQB}

\description{
 Assigns data for Debon & Le Fort's Q vs. B diagram into Figaro template (list '\code{sheet}') and 
 appropriate values into '\code{x.data}' and '\code{y.data}'.  
}

\usage{
DebonQB()
}

\details{
    The Q vs. B diagram was proposed by \emph{Debon and Le Fort (1983)} for aluminous
    associations. It defines three associations, reflecting maficity of samples: 
    leucocratic, subleucocratic and mesocratic.

    Parameters for the diagram are calculated by the function '\code{DebonCalc}'.
    All of them are based on millications (1000 gram-atoms per 100 grams).

    Q = Si / 3 - (K + Na + 2 * Ca / 3)  [cationic proportion of quartz] 

    B = Fe + Mg + Ti [maficity]
    
    \figure{DebonQB.png}
    
    For details, see \emph{Debon & Le Fort (1983)} and \emph{(1988)}.
}

\value{
  \item{sheet}{list with Figaro Style Sheet data}
  \item{x.data}{Q value. See details.}
  \item{y.data}{B value. See details.}
}

\references{
  Debon F & Le Fort P (1983) A chemical-mineralogical classification of common
  plutonic rocks and associations. Trans Roy Soc Edinb; Earth Sci 73: 135-149

  Debon F & Le Fort P (1988) A cationic classification of common plutonic rocks
  and their magmatic associations: principles, method, applications. Bull.
  Mineral 111: 493-511
}

\author{
  Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}

\examples{
    data(blatna)
    accessVar("blatna")
    
    selectSubset("SiO2>50")
    plotDiagram("DebonQB",FALSE)
    figCol("red")
}

\seealso{
  \link{classify}
  \link{figaro}
  \link{plotDiagram}
  \link{DebonPQ}
  \link{DebonBA}
  \link{DebonKNaB}
  \link{DebonBMgNo}
  \link{DebonBQF}
  \link{DebonCalc}
}

\keyword{hplot}
\concept{Plot}
\concept{Grouping}
\concept{Edit}
\concept{Menu: Data handling}
\concept{Menu: Classification}
