\encoding{Windows-1250}
\name{Jensen}
\title{Jensen cation plot (1976)}
\alias{Jensen}

\description{
Assigns data for Jensen's cation plot into Figaro template (list '\code{sheet}') 
and appropriate values into '\code{x.data}' and '\code{y.data}'.  
}

\usage{
Jensen()
}

\details{
Jensen's cation plot, proposed by \emph{Jensen (1976)} and modified by 
\emph{Jensen & Pyke (1982)}. The triangular diagram is defined on the basis of 
millications as follows:

left apex: Al

upper apex: \eqn{Fe^T+Ti}{FeT+Ti}

right apex: Mg

\if{html}{\figure{Jensen.png}} 
\if{latex}{\figure{Jensen.png}{options: width=4.5in}}

The diagram defines following rock series and names:

\tabular{ll}{
\emph{Komatiite series (KOMATIITE)} \tab \emph{Komatiite}\cr
 \tab \emph{Komatiitic basalt}\cr
\emph{Tholeiite series (TH)} \tab \emph{Rhyolite}\cr
 \tab \emph{Dacite}\cr
 \tab \emph{Andesite}\cr
 \tab \emph{High-Fe tholeiite basalt}\cr
 \tab \emph{High-Mg tholeiite basalt}\cr
\emph{Calc-alkaline series (CA)} \tab \emph{Rhyolite}\cr
 \tab \emph{Dacite}\cr
 \tab \emph{Andesite}\cr
 \tab \emph{Basalt}\cr
}
}

\value{
  \item{x.data, y.data}{Values for the three apices transformed into 2D space}
  \item{sheet}{list with Figaro Style Sheet data}
}

\references{
Grunsky EC (1981) An algorithm for the classification of subalkalic volcanic rocks 
using the Jensen cation plot. In: Wood J, White OL, Barlow RB (eds) 
Summary of Field Work, 1981. Ontario Geological Survey, Miscellaneous Papers 100, pp 61-65

Jensen LS (1976) A New Cation Plot for Classifying Subalkalic Volcanic Rocks. 
Ontario Geological Survey Miscellaneous Paper 66,  pp 1-22

Jensen LS, Pyke DR (1982) Komatiites in the Ontario portion of the Abitibi belt. 
In: Arndt NT, Nisbet EG (eds) Komatiites. George Allen & Unwin, London, pp 147-157
}

\author{
  Vojtch Erban, \email{erban@sopky.cz}\cr 
  & Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}

\seealso{
  \link{classify}
  \link{figaro}
  \link{plotDiagram}
}

\examples{
    data(sazava)
    accessVar("sazava")
    
    # Plot the diagram
    plotDiagram("Jensen", FALSE)
}

\keyword{hplot}
\concept{Plot}
\concept{Classification}
\concept{Menu: Classification}
\concept{Menu: Data handling}
