\encoding{Windows-1250}
\name{Enrique}
\alias{Enrique}
\title{or+ab - 2Q - 4an ternary diagram (Enrique 2018)}
\description{
Assigns data for Enrique's diagram into Figaro template (list '\code{sheet}') and                                   
appropriate values into '\code{x.data}' and '\code{y.data}'. The or+ab, 2Q and 4an 
coordinates are assigned into matrix '\code{results}'.    
}

\usage{
Enrique()
}

\details{
This diagram of Enrique (2018), based on CIPW-normative values, is intended to replace the IUGS QAP plot 
(Le Maitre et al 2002) if only chemical, and not modal, analyses are available. 



The apices are defined as follows:

or+ab = based on normative orthoclase and albite in wt. \%

2Q = based on normative quartz in wt. \%

4an = based on normative anorthite in wt. \%

or+ab + 2Q + 4an = 100 \%


The following fields are defined:

\tabular{ll}{ 
1.\tab \emph{quartzolite }\cr
2.\tab \emph{quartz-rich granitoid }\cr
3.\tab \emph{alk-fsp. granite }\cr
4.\tab \emph{syenogranite }\cr
5.\tab \emph{monzogranite }\cr
6.\tab \emph{granodiorite }\cr
7.\tab \emph{tonalite }\cr
8.\tab \emph{tonalgabbro }\cr
9.\tab \emph{tonaleucrite }\cr
10.\tab \emph{alk-fsp quartz syenite }\cr
11.\tab \emph{quartz syenite }\cr
12.\tab \emph{quartz monzonite }\cr
13.\tab \emph{quartz monzodiorite }\cr
14.\tab \emph{quartz diorite }\cr
15.\tab \emph{quartz gabbro}\cr
16.\tab \emph{quartz eucrite }\cr
17.\tab \emph{alkali-feldspar syenite }\cr
18.\tab \emph{syenite }\cr
19.\tab \emph{monzonite }\cr
20.\tab \emph{monzodiorite }\cr
21.\tab \emph{diorite }\cr
22.\tab \emph{gabbroids }\cr
23.\tab \emph{eucritoids}\cr
}
}


\value{
  \item{sheet}{list with Figaro Style Sheet data}
  \item{x.data, y.data}{or+ab,2Q and 4an data (see details) transformed to orthogonal coordinates}
}

\references{
Enrique P (2018) Clasificacin normativa de las rocas plutnicas saturadas y 
sobresaturadas en slice basada en la clasificacin modal QAP: El diagrama 2Q-(or+ ab)-4an. 
Geogaceta 63:95-98
\href{https://sge.usal.es/archivos/geogacetas/geo63/geo63_24.pdf}{online pdf} 

Streckeisen A (1974) Classification and nomenclature of plutonic rocks. Geol 
Rundsch 63: 773-786
\href{http://dx.doi.org/10.1007/BF01820841}{doi: 10.1007/BF01820841} 

Le Maitre R. W. et al. (2002) Igneous Rocks. A Classification and Glossary of Terms. 
2nd edition. Cambridge University Press.
}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}

\seealso{
\link{CIPW}
\link{classify}
\link{figaro}
\link{plotDiagram}
}

\examples{
#plots the or+ab - 2Q - 4an ternary diagram for the current dataset

plotDiagram("Enrique", FALSE)

#classifies the current dataset using the or+ab - 2Q - 4an ternary diagram

classify("Enrique")

}


\keyword{hplot}
\concept{Plot}
\concept{Classification}
\concept{Menu: Classification}
