\encoding{Windows-1250}
\name{Frost}
\alias{Frost}
\title{Frost et al. (2001)}

\description{
    Classification of granitic rocks proposed by \emph{Frost et al (2001)}. 
}

\usage{
    Frost(plot.txt = getOption("gcd.plot.text"), 
    clssf = FALSE, GUI = FALSE)
}

\arguments{
  \item{plot.txt}{logical, annotate fields by their names?}
  \item{clssf}{logical, should the samples be classified?}
  \item{GUI}{logical, is the function called from a GUI?}
}

\details{
    Classification scheme proposed by \emph{Frost et al. (2001)}. It consists of 
    three diagrams:
    \itemize{
    \item \eqn{Fe\ number}{Fe number} vs. \eqn{SiO_{2}}{SiO2} (in wt. \%). 
         NB that the Fe-number is calculated as weight proportion 
         of \eqn{FeO/(FeO+MgO)}{FeO/(FeO+MgO)} 
        (or \eqn{FeO_{tot}/(FeO_{tot}+MgO)}{FeOtot/(FeOtot+MgO)}).
        See also \emph{Warning} below.
        
    \item \eqn{SiO_{2}}{SiO2} (in wt. \%) vs. Modified alkali-lime index (MALI), 
        defined as \eqn{Na_{2}O+K_{2}O-CaO}{Na2O+K2O-CaO} (in wt. \%).

    \item \eqn{SiO_{2}}{SiO2} (in wt. \%) vs. Aluminium saturation index (ASI), 
        defined as molecular
        \eqn{Al_{2}O_{3}/(Na_{2}O+K_{2}O+CaO-3.33 P_{2}O_{5})}{Al2O3/(Na2O+K2O+CaO-1.67 P2O5)}.
    
        In fact, this is the A/CNK parameter of \emph{Shand (1943)}, corrected for the Ca 
        content in apatite. See also \emph{Warning} below.
    }

    The classification is designed to work both with analyses distinguishing between 
    ferrous and ferric iron (preferred) and those with total iron only. The dialogue 
    box lets the user decide, whether to use the ferrous iron value or the total iron.
 
    Similarly, if some \eqn{P_{2}O_{5}}{P2O5} concentrations are missing in the dataset, 
    the user is prompted whether the missing values should be replaced with zero. 
    If not, the problematic analyses are not plotted/classified.
    
    The following associations are distinguished:

        \emph{ferroan}, \emph{magnesian}

        \emph{alkalic}, \emph{alkali-calcic}, \emph{calc-alkalic}, \emph{calcic}

        \emph{peralkaline}, \emph{metaluminous}, \emph{peraluminous}

    \if{html}{\figure{Frost.png}} 
    \if{latex}{\figure{Frost.png}{options: width=5.5in}}

    \if{html}{
        The geologically reasonable combinations, together with examples, 
        are listed in the \url{../Diagrams/Geotectonic/FrostTable.html}, 
        modified from the original article.
    }
    
    In fact, the ASI vs. A/NK diagram (based on  \emph{Shand (1943)}) was not 
    plotted in the paper, but it replaces the conditions mentioned in the text 
    and is, in our view, more instructive.
}

\section{Note}{
    This function uses the plates concept. The individual plots can be selected and their 
    properties/appearance changed as if they were stand alone Figaro-compatible plots. 
    
    See \code{\link{Plate}}, 
    \code{\link{Plate editing}} and 
    \code{\link{figaro}} for details.
    
    Due to the specific design of this scheme (combination of multiple diagrams), 
    the classification option is not available via the pull-down menus. 
    Currently, the only way to apply Frost's classification in \emph{GCDkit} on 
    individual samples is to call the function manually
    from the Console: \code{Frost_2008(clssf = TRUE)}. 
}


\section{Warning}{
    Note that the Fe-number is calculated as weight proportion 
    of  \eqn{FeO/(FeO+MgO)}{FeO/(FeO+MgO)} 
    (or \eqn{FeO_{tot}/(FeO_{tot}+MgO)}{FeOtot/(FeOtot+MgO)}). 
    The approach used here should not be confused with the more common usage
    of the term "Fe-number" (as well as "Mg-number") for molecular proportions.
    
    As approved by one of the authors \emph{(C. Barnes, 
    pers. comm., 2008)}, the equation for ASI in  the original work
    \emph{(Frost et al. 2001)} was stated erroneously as molecular proportions 
    of elements, instead of oxides.       
}

\value{
    \item{results}{The function returns table of calculated coefficients (Fe-Number, MALI, ASI).}

    There are two values for the ASI: that labeled \code{'ASI'} is calculated from molecular 
    proportions of oxides, and is used for plotting and classification.
    The other one is labeled \code{'ASI_orig'}, and is calculated exactly as stated 
    in the original paper (i.e. \eqn{Al/(Ca-1.67P+Na+K)}{Al/(Ca-1.67P+Na+K)}.
}

\section{Note}{
    This function uses the plates concept. The individual plots can be selected and their 
    properties/appearance changed as if they were stand alone Figaro-compatible plots. 
    See \code{\link{Plate}},
     
    \code{\link{Plate editing}} and 
    \code{\link{figaro}} for details.
}

\references{
    Frost BR, Barnes CG, Collins WJ, Arculus RJ, Ellis DJ, Frost CD (2001)
    A geochemical classification for granitic rocks. J Petrol 42: 2033-2048. 
    \doi{10.1093/petrology/42.11.2033}

    Shand SJ (1943) Eruptive rocks, 2nd ed. John Wiley, New York, pp 1-444
}

\author{
  Vojtch Erban, \email{erban@sopky.cz} 
  
  & Vojtch Janouek \email{vojtech.janousek@geology.cz}
}

\seealso{
    \link{Frost_2008}
    \link{Shand}
    \link{classify}
    \link{Plate}
    \link{Plate editing}
    \link{plotPlate}
    \link{figaro}
}


\examples{
#plot the diagrams
plotPlate("Frost")

# Classify the samples, suppress the graphical output
Frost(clssf=TRUE, GUI=TRUE)
}


\keyword{hplot}
\concept{Plot}
\concept{Menu: Geotectonic}
