\encoding{Windows-1250}
\name{Frost_2008}
\alias{Frost_2008}
\title{Frost + Frost (2008)}

\description{
    Classification of feldspathic igneous rocks proposed by \emph{Frost and Frost (2008)}. 
}

\usage{
    Frost_2008(plot.txt = getOption("gcd.plot.text"), 
    clssf = FALSE, GUI = FALSE)
}

\arguments{
  \item{plot.txt}{logical, annotate fields by their names?}
  \item{clssf}{logical, should the samples be classified?}
  \item{GUI}{logical, is the function called from a GUI?}
}

\details{
    Classification scheme originally proposed by \emph{Frost et al. (2001)} for (subalkaline) 
    granitic rocks. It was modified and expanded for alkaline and/or mafic rocks by 
    \emph{Frost and Frost (2008)}. 
    It consists of four diagrams:
    
    
    \itemize{
    \item \eqn{Fe\ number}{Fe number} (\eqn{FeO_{tot}/(FeO_{tot}+MgO)}{FeOtot/(FeOtot+MgO)})
     vs. \eqn{SiO_{2}}{SiO2} (both parameters in wt. \%). See \emph{Warning} below.
     
    \item \eqn{SiO_{2}}{SiO2} (in wt. \%) vs. Modified alkali-lime index (MALI), 
        defined as \eqn{Na_{2}O+K_{2}O-CaO}{Na2O+K2O-CaO} (in wt. \%). 

    \item \eqn{SiO_{2}}{SiO2} (in wt. \%) vs. Aluminium saturation index (ASI), 
        defined as molecular
        \eqn{Al_{2}O_{3}/(Na_{2}O+K_{2}O+CaO-3.33 P_{2}O_{5})}{Al2O3/(Na2O+K2O+CaO-1.67 P2O5)}.
    
        In fact, this is the A/CNK parameter of \emph{Shand (1943)}, corrected for the Ca 
        content in apatite. See also \emph{Warning} below.
        
        If some \eqn{P_{2}O_{5}}{P2O5} concentrations are missing in the dataset, 
        they are replaced by zero. 

    \item Feldspathoid silica-saturation index (FSSI) vs. Alkalinity index (AI), 
        the former based on CIPW-normative minerals: 
        \eqn{(Q-(Lc+2(Ne+Kp)))/100}{(Q-(Lc+2*(Ne+Kp)))/100} 
        and the latter defined as molecular
        \eqn{Al_{2}O_{3}-(Na_{2}O+K_{2}O)}{Al2O3-(Na2O+K2O)}.      
    }
    
    The following associations are distinguished:

        \emph{ferroan}, \emph{magnesian}

        \emph{alkalic}, \emph{alkali-calcic}, \emph{calc-alkalic}, \emph{calcic}

        \emph{peralkaline}, \emph{metaluminous}, \emph{peraluminous}

        \emph{silica-undersaturated}, \emph{silica-saturated}

    \if{html}{\figure{Frost2008.png}} 
    \if{latex}{\figure{Frost2008.png}{options: width=5.5in}}
}


\value{
    \item{results}{The function returns table of calculated coefficients 
        (Fe-number, MALI, ASI, FSSI).}
}

\section{Note}{
    This function uses the plates concept. The individual plots can be selected and their 
    properties/appearance changed as if they were stand alone Figaro-compatible plots. 
    
    See \code{\link{Plate}}, 
    \code{\link{Plate editing}} and 
    \code{\link{figaro}} for details.
    
    Due to the specific design of this scheme (combination of multiple diagrams), 
    the classification option is not available via the pull-down menus. 
    Currently, the only way to apply Frost's classification in \emph{GCDkit} on 
    individual samples is to call the function manually
    from the Console: \code{Frost_2008(clssf = TRUE)}. 
}

\section{Warning}{
    Note that the Fe-number is calculated as weight proportion 
    of \eqn{FeO_{tot}/(FeO_{tot}+MgO)}{FeOtot/(FeOtot+MgO)}. 
    The approach used here should not be confused with the more common usage
    of the term "Fe-number" (as well as "Mg-number") for molecular proportions.
    
    The equation for ASI in  both original works of
    \emph{Frost et al. (2001)} and \emph{Frost and Frost (2008)} was stated 
    erroneously as molecular proportions of elements, instead of oxides. 
    
    The equation for FSSI in \emph{Frost and Frost (2008)} has apparently
    misplaced the outermost brackets, having been originally stated as: 
    \emph{Q-[Lc+2(Ne+Kp)]/100}.   
}



\references{
    Frost BR, Frost CD (2008) A geochemical classification for feldspathic igneous rocks. 
    J Petrol 49:1955-1969.
    \doi{10.1093/petrology/egn054}

    Frost BR, Barnes CG, Collins WJ, Arculus RJ, Ellis DJ, Frost CD (2001)
    A geochemical classification for granitic rocks. J Petrol 42: 2033-2048.
    \doi{10.1093/petrology/42.11.2033} 

    Shand SJ (1943) Eruptive rocks, 2nd ed. John Wiley, New York, pp 1-444 
}

\author{ 
  Vojtch Janouek \email{vojtech.janousek@geology.cz}
  
   &  Vojtch Erban, \email{erban@sopky.cz} 
}

\seealso{
    \link{Frost}
    \link{Shand}
    \link{CIPW}
    \link{classify}
    \link{Plate}
    \link{Plate editing}
    \link{plotPlate}
    \link{figaro}
}

\examples{
#plot the diagrams
plotPlate("Frost_2008")

# Classify the samples, suppress the graphical output
Frost_2008(clssf = TRUE, GUI=TRUE)
}

\keyword{hplot}
\concept{Plot}
\concept{Menu: Geotectonic}
\concept{Menu: Geotectonic}
