\encoding{Windows-1250}
\name{LaurentSource}
\title{Laurent et al. (2014) granitoid sources}
\alias{LaurentSource}

\description{
    Assigns data for a \emph{Laurent et al. (2014)} triangular 
    diagram into Figaro template (list '\code{sheet}') and appropriate values 
    into '\code{x.data}' and '\code{y.data}'.
}

\usage{
LaurentSource()
}

\details{
    Triangular diagram of \emph{Laurent et al. (2014, Fig. 6)} with apices:
    \eqn{Al_{2}O_{3}/(FeOt+MgO)}{Al2O3/(FeOt+MgO)}, 
    \eqn{3CaO}{3CaO}  and 
    \eqn{5K_{2}O/Na_{2}O}{5K2O/Na2O} (all in wt. \%), serves to 
    distinguish prospective sources of granitoids. It is based on compilation of a large
    database of experimental data - see \emph{Laurent et al. (2014 and references therein)} for
    the citations of the original works.

    \if{html}{\figure{LaurentSource.png}} 
    \if{latex}{\figure{LaurentSource.png}{options: width=4.5in}}

    The following sources can be distinguished:
    \tabular{l}{
        Low-K mafic rocks \cr
        High-K mafic rocks \cr
        Tonalites \cr
        Metasediments \cr
    }
}

\value{
\item{sheet}{list with Figaro Style Sheet data}
\item{x.data, y.data}{Al2O3/(FeOt+MgO) - 3CaO - 5K2O/Na2O values recalculated into two dimensions}
}

\references{
    Laurent O, Martin H, Moyen JF, Doucelance R (2014) The diversity and evolution of late-Archean granitoids: 
    evidence for the onset of 'modern-style' plate tectonics between 3.0 and 2.5 Ga. Lithos 205:208-235
    \doi{10.1016/j.lithos.2014.06.012}
}

\author{
    Jean-Franois Moyen, \email{jfmoyen@gmail.com}
    
    Oscar Laurent,  \email{oscarlaurent86@gmail.com}
    }

\examples{
    #plot the diagram
    plotDiagram("LaurentSource",FALSE)
}

\seealso{
\link{figaro}
\link{plotDiagram}
}

\keyword{hplot}
\concept{Geotectonic}
\concept{Plot}
\concept{Menu: Geotectonic}
