\encoding{Windows-1250}
\name{QANOR}
\title{Q'-ANOR diagram (Streckeisen + Le Maitre 1979)}
\alias{QANOR}

\description{
Plots normative Q'-ANOR diagram of  \emph{Streckeisen & Le Maitre (1979)}.
}

\usage{
    QANOR(mesonorm=NULL,new=TRUE)
}

\arguments{
    \item{mesonorm}{numeric, a matrix containing normative minerals calculated, most appropriately, by the function \code{Mesonorm}.}
    \item{new}{logical, is a new plotting window to be opened?}
}

\details{
This function plots Q'-ANOR diagram of \emph{Streckeisen & Le Maitre (1979)} where
Q' = \code{100Qz/(Qz + Or + Ab + An)} and ANOR = \code{100An/(Or + An)} based on 
\emph{eine bessere} Mesonorm for granitoids of \emph{Mielke & Winkler (1979)}. 

    \if{html}{\figure{QANOR.png}} 
    \if{latex}{\figure{QANOR.png}{options: width=5.5in}}

 The fields in this diagram are labeled as follows:

\tabular{ll}{
2 \tab alkali feldspar granite \cr
3 \tab granite \cr
4 \tab granodiorite \cr
5 \tab tonalite \cr
6* \tab quartz alkali feldspar syenite \cr
7* \tab quartz syenite \cr
8* \tab quartz monzonite \cr
9* \tab quartz monzodiorite/quartz monzogabbro \cr
10* \tab quartz diorite/quartz gabbro \cr
6 \tab alkali feldspar syenite \cr
7 \tab  syenite \cr
8 \tab  monzonite \cr
9 \tab  monzodiorite/monzogabbro \cr
10 \tab diorite/gabbro
}
}
 
\references{
Mielke P & Winkler HGF (1979) Eine bessere Berechnung der Mesonorm fuer 
granitische Gesteine. Neu Jb Mineral, Mh 471-480

Streckeisen A & Le Maitre RW (1979) A chemical approximation to the modal 
QAPF classification of the igneous rocks. Neu Jb Mineral, Abh 136: 169-206
}

\seealso{
  \link{classify}
  \link{figaro}
  \link{plotDiagram}
  \link{Mesonorm}
}

\value{
A numeric matrix '\code{results}'. 
}

\examples{
    data(blatna)
    accessVar("blatna")
    
    selectSubset("SiO2>60")
    plotDiagram("QANOR",FALSE)
}


\keyword{manip}
\concept{Menu: Calculations}
\concept{Calculation}
\concept{Norm}

\author{
    Vojtch Janouek, \email{vojtech.janousek@geology.cz} 
    
    & Jean-Franois Moyen \email{jfmoyen@gmail.com}
}
