\encoding{Windows-1250}
\name{addOn}
\alias{addOn}
\title{Replacing missing data by specified values}

\description{
Add missing columns ("what") to a matrix "where", fill with "value".  
}

\usage{
addOn(what,value=NA,where=WR)
}

\arguments{
  \item{what}{character or numeric, specifies the column in the matrix \code{where}}
  \item{value}{numeric vector with the replacement}
  \item{where}{a matrix in which the replacement is to be done}
}

\details{
The function serves two purposes. If a column with the name '\code{what}' does not
exist in the numeric data matrix \code{where}, it appends a new column and fills 
it with '\code{value}'. 

On the other hand, if the column '\code{what}' does exist, the function attempts 
to replace only the empty (NA) values by the specified values '(\code{value})'.

Note that by default, no permanent assignment to the original data matrix is done. 
}

\value{
Returns the modified version of the matrix \code{where}. 
}

\examples{
    data(sazava)
    accessVar("sazava")
    
    # The original version of WR not affected
    addOn("MgO/FeO",WR[,"MgO"]/WR[,"FeOt"])
    
    # Permanent assignment 
    WR<-addOn("MgO/FeO",WR[,"MgO"]/WR[,"FeOt"])
}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}

\keyword{internal}
