\encoding{Windows-1250}
\name{contourAll}
\alias{contourAll}
\alias{chullAll}

\title{
    Outlining the whole dataset in a binary plot 
}
\description{
    These functions outline the whole dataset on a binary plot. Implemented methods are the convex hull or 
    contours. This can be useful for a quick appreciation of the data distribution,
    e.g. in classification diagrams. 
}

\usage{
chullAll(border=NULL, fill=FALSE, ...) 

contourAll(cont.levels = c(0.25,0.50,0.75), n = 20, 
    border = NULL, fill = FALSE, fade.away = TRUE,...)
}

\arguments{
  \item{border}{outline colour.}
  \item{fill}{logical; should be the polygon filled by the border colour?}
  \item{cont.levels}{values (0-1) where contours are to be drawn.}
  \item{n}{density of the grid.}
  \item{fade.away}{logical; shall the colours of individual contours fade away?}
  \item{\dots}{additional parameters to the functions \link{contour} and \link{polygon}, respectively.}
}

\details{
    If not specified, the colours are selected as the most frequently occurring one 
    among the samples within each group. 
    
    For the function \emph{contourAll}, contours are drawn based on percentage of the
    whole population, based on the kernel density estimation. Their smoothness 
    (vs. speed of computation) is determined by the parameter \code{n}.
    The individual contours can be made increasingly more transparent, 
    as controlled by the parameter \code{fade.away}.
    
    \if{html}{\figure{contourAll.png}} 
    \if{latex}{\figure{contourAll.png}}
}

\value{
    Returns (invisibly) a list with two components:
    \item{z}{Values of estimated densities for each of the \code{cont.levels}.}
    \item{kde}{A matrix of the estimated density: rows correspond to the value of \code{x}, columns to the value of \code{y}.}
}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz} and

Jean-Franois Moyen \email{jfmoyen@gmail.com}}

\seealso{
    \link{chull},  \link{optimize} \link{kde2d}
    \link{contour}, \link{polygon}  
    \link{figaro} \link{contourGroups} \link{chullGroups} \link{plotDiagram}
}

\examples{
    data(atacazo)
    accessVar("atacazo")
    
    plotDiagram("TAS",FALSE,TRUE)
    figUser(xlim=c(57,68),ylim=c(4,5.7))
    contourAll(n=10,border="gray",fade.away=FALSE)
    
    figRedraw()
    out<-contourAll(n=50,border="darkgray",fade.away=TRUE)
    
    windows()
    xlab<-.fig.deeval(sheet$demo$call$xlab)
    ylab<-.fig.deeval(sheet$demo$call$ylab)
    persp(out[["All"]]$kde,xlab=xlab,ylab=ylab,main="All")
    
    plotDiagram("PeceTaylor",FALSE,TRUE)
    figUser(xlim=c(55,70),ylim=c(0.5,1.5))
    chullAll(border="darkgray")
    
    chullAll(border="gray",fill=TRUE)
    contourAll(cont.levels=c(0.9,0.5,0.1),border="darkblue",fade.away=FALSE,lty="dashed")
}    

\keyword{aplot}
\keyword{iplot}
\concept{Plot}
\concept{Figaro}
\concept{Menu: Plot editing}
