\encoding{Windows-1250}
\name{correlationCoefPlot}
\title{Statistics: Correlation coefficient patterns}
\alias{Correlation coefficient patterns}
\alias{correlationCoefPlot}

\description{
    Produces set of plots of correlation coefficient patterns, for the entire dataset or
    separately for each group. 
}

\usage{
correlationCoefPlot(elems = NULL, groups = NULL, method = "pearson", 
    use = "pairwise.complete.obs")
}

\arguments{
    \item{elems}{list of desired elements}
    \item{groups}{a character vector with grouping information}
    \item{method}{a character string indicating which correlation 
        coefficient (or covariance) is to be computed}
    \item{use}{an optional character string giving a method for 
        computing covariances in the presence of missing values}
}

\details{
    This function calculates and plots correlation coefficient patterns either for 
    the whole dataset (if '\code{groups} = NULL') or by individual groups. 
    
    For meaning of parameters '\code{methods}' and '\code{use}', see \code{\link{cor}}. 
    
    The utility of pairwise correlation coefficient patterns was demonstrated by 
    \emph{Rollinson (1993 and references therein)}. In principle, a similarity 
    in correlation patterns between two or more elements means their analogous 
    geochemical behaviour, potentially reflecting the operation of the same 
    petrogenetic/geological process (fractional crystallization, 
    partial melting, weathering, hydrothermal alteration...)
    
    \if{html}{\figure{correlationCoefPlot.png}} 
    \if{latex}{\figure{correlationCoefPlot.png}{options: width=5.5in}}

    The variables are selected using the function '\code{\link{selectColumnsLabels}}'.
}

\value{
    A list with the values of pairwise correlation in the whole dataset or in each
    of the groups.
}

\examples{
    data(atacazo)
    accessVar("atacazo")
    
    # The whole dataset
    correlationCoefPlot(elems="K,Rb,Ba,Sr,Cr,Ni,Zr,Nb,Ti")
    
    # By currently defined groups 
    groupsByLabel("Volcano")
    correlationCoefPlot(elems="K,Rb,Ba,Sr,Cr,Ni,Zr,Nb,Ti",groups)
}

\references{
    Rollinson HR (1993) Using Geochemical Data: Evaluation, Presentation, 
    Interpretation. Longman, London, p. 1-352
}

\seealso{
\code{\link{cor}}
}

\keyword{hplot}
\concept{Statistics}
\concept{Plot}
\concept{Menu: Calculations: Statistics}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}

