\encoding{Windows-1250}
\name{Plate editing}
\alias{Plate editing}
\alias{plateUser}
\alias{plateCex}
\alias{plateCexLab}
\alias{plateCexMain}
\alias{plateAnnotationsRemove}
\alias{platePch}
\alias{plateCol}
\alias{plateBW}
\alias{plateXLim}
\alias{plateYLim}
\alias{plate0YLim}
\alias{plateExpand}
\alias{plateExtract}

\title{Editing the plate properties/all its plots simultaneously}

\description{
    A collection of functions to modify the  properties of a plate (or all 
    its diagrams) simultaneously.
}

\usage{
plateUser(...)
   
plateCex(n=NULL)

plateCexMain(n=NULL)

plateCexLab(n=NULL)

plateAnnotationsRemove()

platePch(pch=NULL)

plateCol(col=NULL)

plateBW()

plateXLim(xlim=NULL)
    
plateYLim(ylim=NULL)
    
plate0YLim()
    
plateExpand(scr=NULL)
    
plateExtract(diagram,which=NULL,main=NULL,calc.only=FALSE,...)
}


\arguments{
  \item{...}{
    (for \code{plateUser}): list of arguments passed to the function \code{'figUser'}
    (for \code{plateExtract}): additional parameters to the diagram (plate) plotting function.
  }
  \item{n}{relative size (use n = 1 for standard one).}   
  \item{pch}{plotting symbol specification, either as string or a numeric code (\link{showSymbols}).}  
  \item{col}{colour specification, either by its English name, or by a numeric code (\link{showColours}).}
  \item{xlim}{scaling for the x axis.}
  \item{ylim}{scaling for the y axis.}
  \item{scr}{number of screen to be expanded.}
  \item{diagram}{name of the plotting function producing a plate.}
  \item{which}{sequential number of plot in its definition.}
  \item{main}{optional alternative main title to the diagram.}
  \item{calc.only}{logical; should be performed only calculations, without plotting?}
}

\details{
    Most of these functions serve to simultaneously change properties of all individual 
    diagrams forming the given plate. 
    They can be used to set up a uniform size of plotting symbols (\code{'plateCex'}), 
    scaling the main title (\code{'plateCexMain'}), set up a uniform size of   
    the axes' labels (\code{'plateCexLab'}), remove the annotations 
    of classification fields (\code{'plateAnnotationsRemove'}), 
    specifying a uniform plotting symbol 
    (\code{'platePch'}) and/or colour
    (\code{'plateCol'}) to all plots, or set 
    them into black and white (\code{'plateBW'}).
    
    Several parameters can be changed at the same time,
    using the powerful function \code{'plateUser'}. It simply
    passes all its arguments to the function \code{'figUser'}, invoked for 
    modification of each of the individual slots.
    
    If the same variable is plotted as x or y axis in all diagrams forming the plate 
    (e.g., on Harker plots), it can be
    scaled at once by means of the functions \code{'plateXLim'} and \code{'plateYLim'}.
    Using the command \code{'plate0YLim'} it is possible to set the origin of all 
    non-logarithmic y axes to zero.
    
    The function \code{'plateExpand'} displays an expanded version of the selected 
    diagram in a separate window. 
    
    The function \code{'plateExtract'} extracts a Figaro definition of a single plot
    from a plate normally plotted by the function \code{'diagram'}. 
    If \code{'calc.only'} is \code{'FALSE'}, the diagram is displayed, 
    either in a separate window or in the current slot, if the active graphical window 
    contains a plate.    
}


\value{
    None.
}

\seealso{
  \link{Plate}, \link{plotPlate},  \link{figaro},  \link{figUser}, \link{par},
  \link{figCol},  \link{figScale},  
  \link{showSymbols},  \link{showColours}
}

\examples{
    data(sazava)
    accessVar("sazava")

    multiplePerPage(which=c("binary(\"K2O/Na2O\",
        \"Rb\",new=FALSE)","DebonPQ","DebonBMgNo","AFM","PeceTaylor","Shand"))
    plateCex(0.5)

    plateCex(2)
    platePch(11)

    platePch("+")
    plateCol(11)

    plateCol("red")
   
    plateBW()

    # For power users
    plateUser(las=3,cex=2.5,col="darkred",cex.axis=1.5,cex.lab=1.8)
   
    # Harkers
    multiple("SiO2",major)
    plateCex(2)
    plateXLim(c(50,70))
    plate0YLim()
   
    # Spiders
    groupsByLabel("Intrusion")
    spider(WR,selectNorm("Boynton"),0.1,1000,pch=labels$Symbol,col=labels$Colour,cex=2)
    figMulti(plot.symb=TRUE)
    plateYLim(c(1,100))
   
    plateExpand(2)

    # Second plot of Pearce et al. (1984), i.e. Y-Nb   
    graphicsOff()
    plateExtract("PearceGranite",2) 
}

\keyword{hplot}
\concept{Plot}
\concept{Plates}
\concept{Menu: Plots}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}

\references{
Pearce JA, Harris NW & Tindle AG (1984) Trace element 
discrimination diagrams for the tectonic interpretation of granitic rocks. 
J Petrology 25: 956-983. 
\doi{10.1093/petrology/25.4.956 }
}
