\encoding{Windows-1250}
\name{filledContourFig}
\title{Filled contours plot}
\alias{filledContourFig}

\description{
Generates a frequency plot on the basis of the most recently plotted Figaro 
template. 
}

\usage{
filledContourFig(palette="heat.colors",grid.density=NULL,overplot=FALSE,
xlab=sheet$demo$call$xlab,ylab=sheet$demo$call$ylab,
xlim=sheet$demo$call$xlim,ylim=sheet$demo$call$ylim,
annotate.fields=FALSE,...)
}

\arguments{
  \item{palette}{character; name of the palette}
  \item{grid.density}{numeric; density of the grid along the x and y axes}
  \item{overplot}{logical; should be the diagram overplotted by the original dataset?}
  \item{xlab}{character vector; label for the x axis}
  \item{ylab}{character vector; label for the y axis}
  \item{xlim}{limits for the x axis}
  \item{ylim}{limits for the y axis}
  \item{annotate.fields}{logical; should be the plotted fields labeled by their names?}
  \item{...}{additional plotting parameters}
}

\details{
This is a somewhat modified version of the R function '\code{\link{filled.contour}}' 
that produces a frequency plot on the basis of a Figaro template and superimposes, 
if desired, selected data points. 

    \if{html}{\figure{filledContoursFig.png}} 
    \if{latex}{\figure{filledContoursFig.png}{options: width=4.5in}}
    
The user can specify how many intervals should be each of the axes split 
into ('\code{grid.density}'). This corresponds to a density of the grid, 
in which are the individual points classified into. A bit of experimenting 
with this values is usually needed. 
Then a colour scheme ('\code{palette}') can be chosen. 
After the frequency plot is generated, selected analyses 
can be plotted on the top (\code{'overplot'}). 
}

\value{
None.
}

\seealso{
'\code{\link{addContours}}'  '\code{\link{figaro}}'  '\code{\link{selectPalette}}'
}

\examples{
    data(atacazo)
    accessVar("atacazo")

    plotDiagram("TAS",FALSE,TRUE)
    filledContourFig(palette="heat.colors",grid.density=50)
    
    # User-defined palette
    plotDiagram("TAS",FALSE,TRUE)
    my.palette<-colorRampPalette(c("darkred", "red","pink", "white"),space = "rgb")
    filledContourFig(palette="my.palette",grid.density=15,xlim=c(58,70),ylim=c(0,10))
}

\keyword{hplot}
\concept{Plot}
\concept{Figaro}
\concept{Statistics}
\concept{Menu: Plot editing}

\author{
    Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}
