\encoding{Windows-1250}
\name{scattersmooth}
\title{scattersmooth}
\alias{scattersmooth}

\description{
Plotting scatterplot with smoothed densities (smoothed two-dimensional histogram)
after \emph{Eilers & Goeman (2004)}.
}

\usage{
scattersmooth(xlab = NULL, ylab = NULL, samples = NULL, nbin = 100, lambda = 1,
    pal = heat.colors(100), pch = 15, col = "blue", cex = 0.3, 
    xlim = NULL, ylim = NULL, ...)
}

\arguments{
\item{xlab, ylab}{character; specification of the plotting variables (formulae OK).}
\item{samples}{character or numeric vector; specification of the samples to be plotted.}
\item{nbin}{integer, giving the number of bins for x and y, or a vector with two integers.}
\item{lambda}{the smoothing parameter; larger lambda gives smoother curves.}
\item{pal}{specification of a palette yielding colours for filled contours.}
\item{pch}{plotting symbols.}
\item{col}{plotting colours.}
\item{cex}{relative size of plotting symbols.}
\item{xlim}{limits of the x axis.}
\item{ylim}{limits of the y axis.}
\item{...}{Further parameters to the original function.}
}

\details{
The function produces a scatterplot with smoothed densities (smoothed two-dimensional histogram). 
The code has been adopted, with only small modifications and new interface to GCDkit, from the original R 
functions designed by \emph{Eilers & Goeman (2004)}.The original scatterplot function has been renamed 
to '\code{.scattersmoothMain}'.  

The complete dataset:
\if{html}{\figure{scattersmoothbefore.png}{options: width=500 alt="SiO2-A/CNK plot" style="vertical-align:top"}}
    \if{latex}{\figure{scattersmoothbefore.png}{options: width=4in}}

If plotted with \code{lambda=1}:
\if{html}{\figure{scattersmootha.png}{options: width=500 alt="SiO2-A/CNK plot smoothed with lambda = 1" style="vertical-align:top"}}
    \if{latex}{\figure{scattersmootha.png}{options: width=4in}}


If plotted with \code{lambda=100}:
\if{html}{\figure{scattersmoothb.png}{options: width=500 alt="SiO2-A/CNK plot smoothed with lambda = 100" style="vertical-align:top"}}
    \if{latex}{\figure{scattersmoothb.png}{options: width=4in}}


The variables to be plotted are selected using the function 
'\code{\link{selectColumnLabel}}'. In the specification of the variables can 
be used also arithmetic expressions, see \code{\link{calcCore}} for the correct 
syntax.

The samples can be selected based on combination of three searching 
mechanisms (by sample name/label, range or a Boolean condition) - see 
\code{\link{selectSubset}} for details. 
}

\section{Warning}{
The function is NOT Figaro-compatible.
}

\value{
Returns (invisibly) all parameters calculated by the original function.
}

\references{
Eilers PHC, Goeman JJ (2004) Enhancing scatterplots with smoothed densities. Bioinformatics 20: 623-628
}


\examples{
    data(atacazo)
    accessVar("atacazo")
    
    scattersmooth("SiO2","A/CNK",xlim=c(55,67),ylim=c(0.7,1.2),pal=heat.colors(100),lambda=1)

    scattersmooth("SiO2","A/CNK",xlim=c(55,67),ylim=c(0.7,1.2),pal=heat.colors(100),pch=17,
        col="black",cex=1,lambda=100)
}

\keyword{hplot}
\concept{Plot}
\concept{Menu: Plugins}

\author{
  Paul H. C Eilers, \email{p.eilers@erasmusmc.nl} 
  
  & Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}

