\encoding{Windows-1250}
\name{DebonBQF}
\title{BQF ternary diagram (Debon + Le Fort 1983)}
\alias{DebonBQF}

\description{
 Assigns data for Debon & Le Fort's BQF ternary diagram into Figaro template (list '\code{sheet}') and 
 appropriate values into '\code{x.data}' and '\code{y.data}'.  
}

\usage{
DebonBQF(reference.rocks=TRUE)
}

\arguments{
    \item{reference.rocks}{logical; should be the ideal rock compositions also plotted?.}
}

\details{
    The BQF diagram as proposed by \emph{Debon and Le Fort (1983)} expresses balance of three
    main groups of rock-forming minerals, dark minerals (B), quartz (Q) and 
    feldspars with muscovite (F).

    Parameters for the diagram are calculated by the function '\code{DebonCalc}'.
    All of them are based on millications (1000 gram-atoms per 100 grams) and named
    as follows:

    Q(quartz)

    B(dark m.)
 
    F(feldsp)
    
    \figure{DebonBQF.png}
    
    Optionally, if, \code{reference.rocks = TRUE}, twelve average chemical compositions of 
    common igneous rocks are also plotted, as follows: 
    
    \tabular{lll}{
        \bold{label}\tab \bold{plutonic rock}\cr
        go\tab \emph{gabbro}\cr
        mzgo\tab \emph{monzogabbro}\cr
        mz\tab \emph{monzonite}\cr
        s\tab \emph{syenite}\cr
        dq\tab \emph{quartz diorite}\cr
        mzdq\tab \emph{quartz monzodiorite}\cr
        mzq\tab \emph{quartz monzonite}\cr
        sq\tab \emph{quartz syenite}\cr
        to\tab \emph{tonalite}\cr
        gd\tab \emph{granodiorite}\cr
        ad\tab \emph{adamellite}\cr
        gr\tab \emph{granite}
    } 

    For details, see \emph{Debon & Le Fort (1983)} or \emph{(1988)}.
}

\value{
  \item{sheet}{list with Figaro Style Sheet data}
  \item{x.data, y.data}{Q(quartz), B(dark m.) and F(feldsp) values (see details) transformed into 2D}
}

\references{
  Debon F & Le Fort P (1983) A chemical-mineralogical classification of common
  plutonic rocks and associations. Trans Roy Soc Edinb; Earth Sci 73: 135-149

  Debon F & Le Fort P (1988) A cationic classification of common plutonic rocks
  and their magmatic associations: principles, method, applications. Bull.
  Mineral 111: 493-511
}

\author{
  Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}

\examples{
    data(blatna)
    accessVar("blatna")
    
    plotDiagram("DebonBQF",FALSE,reference.rocks=TRUE)
    figCol("red")
}

\seealso{
  \link{classify}
  \link{figaro}
  \link{plotDiagram}
  \link{DebonPQ}
  \link{DebonBA}
  \link{DebonQB}
  \link{DebonKNaB}
  \link{DebonBMgNo}
  \link{DebonCalc}
}

\keyword{hplot}
\concept{Plot}
\concept{Grouping}
\concept{Edit}
\concept{Menu: Data handling}
\concept{Menu: Classification}
