\encoding{Windows-1250}
\name{DebonKNaB}
\title{K/(Na+K) vs. B diagram (Debon + Le Fort 1983)}
\alias{DebonKNaB}

\description{
 Assigns data for Debon & Le Fort's K/(Na+K) vs. B diagram into Figaro template (list '\code{sheet}') and 
 appropriate values into '\code{x.data}' and '\code{y.data}'.  
}

\usage{
DebonKNaB()
}

\details{
    The K/(Na+K) vs. B diagram was proposed by \emph{Debon and Le Fort (1988)} for aluminous
    magmatic suites. It defines three associations based on the balance of the two alkalis, 
    namely potassic, sodi-potassic and sodic (note that the x axis is reversed). 
    Moreover, leucocratic, subleucocratic and mesocratic associations are distinguished based
    on maficity of the samples.

    Parameters for the diagram are calculated by the function '\code{DebonCalc}'.
    All of them are based on millications (1000 gram-atoms per 100 grams).

    K/(Na + K) [alkali ratio]

    B = Fe + Mg + Ti [maficity]
    
    \figure{DebonKNaB.png}

    For details, see \emph{Debon & Le Fort (1983)} or \emph{(1988)}.
}

\value{
  \item{sheet}{list with Figaro Style Sheet data}
  \item{x.data}{K/(Na + K) value. See details.}
  \item{y.data}{B value. See details.}
}

\references{
  Debon F & Le Fort P (1983) A chemical-mineralogical classification of common
  plutonic rocks and associations. Trans Roy Soc Edinb; Earth Sci 73: 135-149

  Debon F & Le Fort P (1988) A cationic classification of common plutonic rocks
  and their magmatic associations: principles, method, applications. Bull.
  Mineral 111: 493-511
}

\author{
  Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}

\examples{
    data(blatna)
    accessVar("blatna")
    
    selectSubset("SiO2>50")
    plotDiagram("DebonKNaB",FALSE)
    figCol("red")
}

\seealso{
  \link{classify}
  \link{figaro}
  \link{plotDiagram}
  \link{DebonPQ}
  \link{DebonBA}
  \link{DebonQB}
  \link{DebonBQF}
  \link{DebonBMgNo}
  \link{DebonCalc}
}

\keyword{hplot}
\concept{Plot}
\concept{Grouping}
\concept{Edit}
\concept{Menu: Data handling}
\concept{Menu: Classification}
