\encoding{Windows-1250}
\name{contourGroups}
\alias{contourGroups}
\alias{chullGroups}

\title{
    Outlining individual groups of samples in a binary plot 
}
\description{
    These functions outline the individual clusters of data (groups by default) 
    on a binary plot. Implemented methods are the convex hull or 
    contours. This can be useful for a quick appreciation of the data distribution,
    e.g. in classification diagrams. 
}

\usage{
chullGroups(clusters = groups, border = NULL, fill = FALSE,...)

contourGroups(clusters = groups, cont.levels = c(0.25,0.50,0.75), n = 20, 
    border = NULL, fill = FALSE, fade.away = TRUE,...)
}

\arguments{
  \item{clusters}{grouping information for each of the samples.}
  \item{border}{outline colours.}
  \item{fill}{logical; should be the polygons filled by the border colour?}
  \item{cont.levels}{values (0-1) where contours are to be drawn.}
  \item{n}{density of the grid.}
  \item{fade.away}{logical; shall the colours of individual contours fade away?}
  \item{\dots}{additional parameters to the functions \link{contour} and \link{polygon}, respectively.}
}

\details{
    If not specified, the colours are selected as the most frequently occurring one 
    among the samples within each group. 
    
    For the function \emph{contourGroups}, contours are drawn based on percentage of the
    whole population, based on the kernel density estimation. Their smoothness 
    (vs. speed of computation) is determined by the parameter \code{n}.
    The individual contours can be made increasingly more transparent, 
    as controlled by the parameter \code{fade.away}.
    
    \if{html}{\figure{contourGroups.png}} 
    \if{latex}{\figure{contourGroups.png}}

}

\value{
    Returns (invisibly) a list with two components:
    \item{z}{Values of estimated densities for each of the \code{cont.levels}.}
    \item{kde}{A matrix of the estimated density: 
        rows correspond to the value of \code{x}, columns to the value of \code{y}.}
}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz} and

Jean-Franois Moyen \email{jfmoyen@gmail.com}}


\seealso{
    \link{chull},  \link{optimize} \link{kde2d}
    \link{contour}, \link{polygon}  
    \link{figaro} \link{contourAll} \link{chullAll} \link{plotDiagram}
}

\examples{
    data(atacazo)
    accessVar("atacazo")
    groupsByLabel("Volcano")
    
    plotDiagram("TAS",FALSE,TRUE)
    figUser(xlim=c(57,68),ylim=c(4,5.7))
    contourGroups(n=10,fade.away=FALSE)
    
    figRedraw()
    out<-contourGroups(n=50,fade.away=TRUE)
    
    windows()
    xlab<-.fig.deeval(sheet$demo$call$xlab)
    ylab<-.fig.deeval(sheet$demo$call$ylab)
    persp(out[["Atacazo"]]$kde,xlab=xlab,ylab=ylab,main="Atacazo")

    plotDiagram("PeceTaylor",FALSE,TRUE)
    figUser(xlim=c(55,70),ylim=c(0.5,1.5))
    chullGroups()
    
    chullGroups(fill=TRUE)
    
    figRedraw()    
    contourGroups(cont.levels=c(0.9,0.5,0.1),border="darkgray",fade.away=FALSE,lty="dashed")
}    

\keyword{aplot}
\keyword{iplot}
\concept{Plot}
\concept{Figaro}
\concept{Menu: Plot editing}
