\encoding{Windows-1250}
\name{figMulti}
\title{Figaro: Multiple plot by groups}
\alias{figMulti}

\description{
    Displays multiple plots, for each of the groups one, based on a most recently 
    plotted Figaro-compatible template. For spiderplots, the colour field denotes the total 
    variation with the whole dataset.
}

\usage{
figMulti(x=x.data,y=y.data,nrow=NULL,ncol=NULL,xlab=sheet$demo$call$xlab,
    ylab=sheet$demo$call$ylab,pch=NULL,col=NULL,
    cex = NULL,plot.symb=NULL,shaded.col="gray",title=NULL,...)
}

\arguments{
  \item{x, y}{data to be plotted}
  \item{nrow, ncol}{dimensions of the plots' matrix}
  \item{xlab, ylab}{labels for the axes}
  \item{pch}{plotting symbols (except for spiders)}
  \item{col}{plotting colours (except for spiders)}
  \item{cex}{relative size of the plotting symbols (except for spiders)}
  \item{plot.symb}{logical, spiders. Shall be shown also plotting symbols or just lines?}
  \item{shaded.col}{(spiders) Colour for the field portraying the overall variability in the dataset.}
  \item{title}{optional title for the whole plate. If not provided, it is taken from the title of the Figaro template.}
  \item{...}{any additional graphical parameters}
}

\section{Note}{
    This function uses the plates concept. The individual plots can be selected and their 
    properties/appearance changed as if they were stand alone Figaro-compatible plots. 
    See \code{\link{Plate}}, \code{\link{Plate editing}} and 
    \code{\link{figaro}} for details.
}

\section{Details}{
    The function can handle any Figaro-compatible plots, including binary, ternary or
    spiderplots. For classification plots, it may be advantageous to switch off the 
    field names using the function \code{'figRemove'}  
    (see the figure below as well as the Examples).
    
    For spiderplots, it is advantageous to set up most of the plotting properties
    before the function \code{'figMulti'} is invoked. 
    
    \if{html}{\figure{figMulti.png}} 
    \if{latex}{\figure{figMulti.png}{options: width=5.5in}}
} 
    
\seealso{
    \link{figaro},  \link{Plate},  \link{Plate editing}
    \link{binary}, \link{ternary},  \link{spider} 
}

\examples{
    data(blatna)
    accessVar("blatna")
    groupsByLabel("Suite")
    # Note that groups should have been defined before running these examples. 

    # switching on the field names (default, valid globally for the whole system)
    options("gcd.plot.text"=TRUE)
    plotDiagram("TAS",FALSE)

    # switching off the field names (temporarily, for the given plot)
    plotDiagram("LarochePlut",FALSE)
    figRemove()
    figMulti(col="black",pch="*",cex=3)

    # spiders
    spider(WR,"Boynton",0.1,1000,cex=2,col="red")
    figMulti(plot.symb=TRUE)
    plateCexLab(1.3)

    spider(WR,"Boynton",0.1,1000,col="red",xrotate=FALSE,offset=TRUE)
    figMulti(plot.symb=FALSE)
    plateCexLab(1.3)

    spider(WR,"Boynton",0.1,1000,xrotate=TRUE,offset=TRUE)
    figMulti(plot.symb=FALSE,shaded.col="lightblue")
    plateCexLab(1.3)
}

\author{
    Vojtch Janouek, \email{vojtech.janousek@geology.cz} 
    
    and Colin M. Farrow, \email{colinfarrow537@gmail.com}
}

\keyword{hplot}
\concept{Plot}
\concept{Figaro}
\concept{Menu: Plot editing}
\concept{Grouping}
