\encoding{Windows-1250}
\name{figUser}
\title{Plot editing: User defined parameter}
\alias{figUser}

\section{Menu}{
    Plot editing: User defined parameter
}

\description{
    Enables the power users to modify the plotting parameters directly,
    one or several at the time. 
}

\usage{
    figUser(expression=NULL,...,redraw=TRUE)
}


\arguments{
    \item{expression}{character; single text string to be evaluated that contains parameters to be changed.}
    \item{...}{(alternative) list of named parameters to be changed.}
    \item{redraw}{logical; should be the modified Figaro template redrawn?}
}

\details{
The parameters can be specified at the function call, either as a single expression (text string) or 
as a list of named parameters in the form \code{par.name = value}  (see examples). 
If neither is specified, the parameters are chosen by a GUI dialogue. 
If no parameters are entered from the GUI, they can be chosen from a list (still experimental!)

Several of parameters can be entered simultaneously. 

NB that in the single text expression, quotation marks need to be preceded by backslashes as an 
escape character. In the expression, individual parameters are to be separated by semicolons. 

Arguably the most useful parameters are (see \link{par} for further possibilities):

\tabular{ll}{

main \tab main title  \cr 
sub \tab sub title  \cr
xlab \tab label of x axis \cr
ylab \tab label of y axis \cr
xlim \tab limits for the x axis \cr
ylim \tab limits for the y axis \cr
bg \tab colour of background \cr
pch \tab plotting symbols\cr 
col \tab colour of plotting symbols\cr 
cex \tab relative size of plotting symbols\cr
cex.axis \tab magnification for axis annotation\cr
cex.lab \tab magnification for x and y labels\cr
cex \tab relative size of plotting symbols\cr
log \tab which of the axes is logarithmic? (\code{"","x","y"} or \code{"xy"})\cr 
}

}


\section{Warning}{
If requesting a logarithmic plot, do make sure that the axis ranges are all positive. 
See Examples or invoke menu items '\code{Plot editing: Scale x axis}' and 
'\code{Plot editing: Scale y axis}'.
}
 
\seealso{
 \link{figaro}, \link{par},  \link{plateUser}  
}

\examples{
    data(blatna)
    accessVar("blatna")

    plotDiagram("DebonPQ",FALSE,TRUE)
    figUser(pch="+")

    figUser(col="darkblue")

    figUser(pch=1,col=2,cex=1.5)

    figUser(bg="khaki", cex=1.5) # for camouflage purposes

    # For power users
    figUser(main="My plot 1", las=3, col.main="blue", cex.main=2.5, cex.lab=1.8, cex.axis=0.75)

    # Alternative syntax
    figUser("main=\"My plot 2\"; las=2; cex.lab=1.2; cex.axis=1; col.main=\"darkred\"")
}

\keyword{aplot}
\keyword{color}
\keyword{iplot}
\concept{Plot}
\concept{Figaro}
\concept{Menu: Plot editing}

\author{
Colin M. Farrow, \email{colinfarrow537@gmail.com} 

and Vojtch Janouek, \email{vojtech.janousek@geology.cz}
}
