\encoding{Windows-1250}
\name{Molecular weights}
\alias{molecularWeight}
\alias{MW}
\title{Calculating molecular weights of oxides}

\description{
    Calculates molecular weights for simple oxide formula(e).
}

\usage{
molecularWeight(formula) 
}

\arguments{
    \item{formula}{a character vector with formula(e) of the oxide(s).}
}

\details{
    So far only simple oxide formulae in form of \eqn{A_{x}O_{y}}{AxOy} (where x, y are optional indexes)
    can be handled. The atomic weights are stored in a file \code{MW.data} in the main directory. 
    The atomic weights come from official CIAAW  web site 
    \href{https://www.ciaaw.org}{https://www.ciaaw.org}.  
}

\value{
    A list with items:
    \tabular{ll}{
        MW \tab molecular weight(s) \cr
        x.atoms \tab number(s) of atoms in the formula\cr
        x.oxygen \tab number(s) of oxygens
    }
}

\references{
    Commission on Isotopic Abundances and Atomic Weights (CIAAW) of the 
    International Union of Pure and Applied Chemistry. 
    Accessed on January 8, 2016, at 
    \href{https://www.ciaaw.org}{https://www.ciaaw.org} 
}


\examples{
    molecularWeight("SiO2")
    molecularWeight("SiO2")[[1]]

    MW["SiO2"]
    MW[major]
    mw["Si"]

    oxides<-c("SiO2","TiO2","Al2O3","Fe2O3","FeO")
    sapply(oxides,molecularWeight)
}

\keyword{manip}
\concept{Calculation}

\author{
Vojtch Janouek, \email{vojtech.janousek@geology.cz} and 
Vojtch Erban, \email{erban@sopky.cz}
}
