\encoding{Windows-1250}
\name{pairsCorr}
\title{Statistics: Correlation}
\alias{Statistics: Correlation: majors}
\alias{Statistics: Correlation: traces}
\alias{pairsMjr}
\alias{pairsTrc}
\alias{pairsCorr}
\alias{panel.cor}
\alias{panel.cov}
\alias{panel.hist}
\alias{panel.smooth}

\usage{
pairsCorr(elems=NULL,pch=NULL,col=NULL,upper.panel="panel.cor",...)

pairsMjr(pch=NULL,col=NULL,upper.panel="panel.cor",...)

pairsTrc(pch=NULL,col=NULL,upper.panel="panel.cor",...)
}

\description{
    Plots a matrix of scatterplots in the lower panel and one of other pre-defined 
    panel functions in the upper. 
}

\arguments{
\item{elems}{list of desired elements/oxides}
\item{pch}{plotting symbols}
\item{col}{colours}
\item{upper.panel}{character; name of the function to be used for the upper plate}
\item{...}{any further parameters to the function \code{\link{pairs}}}
}

\details{
The samples can be selected based on combination of three searching mechanisms 
(by sample name/label, range or a Boolean condition) - see 
\code{\link{selectSamples}} for details. 

Even though a list of major elements is assumed as a default, different 
variables can be specified by the function '\code{\link{selectColumnsLabels}}'.

In the specification of the variables can be used also arithmetic expressions, 
see \code{\link{calcCore}} for the correct syntax.

\if{html}{\figure{pairsCorr.png}} 
\if{latex}{\figure{pairsCorr.png}{options: width=5.5in}}

The upper panels to choose from are:
    
    \tabular{lll}{
    Parameter \tab Function \tab Explanation \cr
    '\code{panel.corr}'   \tab \link{cor}    \tab Prints correlations, with size proportional to the correlations; \cr 
    '\code{panel.cov}'    \tab \link{cov}    \tab Prints covariances; \cr
    '\code{panel.smooth}' \tab \link{lowess} \tab Fits smooth trendlines; \cr
    '\code{panel.hist}'   \tab \link{hist}   \tab Plots frequency histograms. \cr
   }
}

\value{
    Returns a variable '\code{results}' with the outcome of the function
    used for the upper panel construction  
    (\link{cor} for '\code{panel.corr}' or \link{cov} for '\code{panel.cov}').
}

\examples{
    data(blatna)
    accessVar("blatna")
    
    pairsCorr(LILE)
    
    pairsCorr(LILE,pch="+",col="darkgreen",cex.labels=3,upper.panel="panel.smooth")

    pairsMjr(pch=15,col="red")

    pairsTrc(pch=15,col="red")

    # user-defined list
    my.elems<-c("Na2O/K2O","Rb","Sr","Ba")
    pairsCorr(my.elems,col="darkblue")
}


\seealso{
\link{pairs}
\link{cor}
\link{cov}
\link{lowess}
\link{hist}
}

\keyword{hplot}
\keyword{multivariate}
\concept{Statistics}
\concept{Plot}
\concept{Menu: Calculations: Statistics}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}
