\encoding{Windows-1250}
\name{plotDiagram}
\alias{plotDiagram}

\title{Plot Classification Diagram}
\description{
  Plots the classification diagram, stored in the Figaro style sheet. 
}

\usage{
    plotDiagram(diagram,select.samples=TRUE,new=TRUE,main=NULL,width=6.5,height=6.5,pointsize=10,
        bg="transparent",autoscale=TRUE,interactive=FALSE,...)
}

\arguments{
  \item{diagram}{a valid name of the classification diagram. See details.}
  \item{main}{optional alternative main title to the diagram.}
  \item{select.samples}{logical; should be invoked the dialogue for selecting samples?}
  \item{new}{logical; should be opened a new plotting window?}
  \item{width, height}{dimensions of the plotting window in inches.}
  \item{pointsize}{the default pointsize of plotted text, interpreted as big points (1/72 inch).}
  \item{bg}{plotting window background colour.}
  \item{autoscale}{logical; when some data fall outside the plot, display a dialogue to autoscale?}
  \item{interactive}{logical; for internal use by our French colleagues.}
  \item{...}{optional parameters to the plotting function}
}

\details{
The argument '\code{diagram}' may acquire one of following values:

\preformatted{
    
'AFM', 'Miyashiro', 'PeceTaylor', 'Hastie', 'NaAlK', 

'Shand', 'TAS', 'CoxVolc', 'TASMiddlemostVolc', 

'Jensen', 'LarocheVolc', 'WinFloyd1', 

'Pearce1996', 'WinFloyd2', 'QAPFVolc', 'OConnorVolc',

'CoxPlut', 'TASMiddlemostPlut', 'LarochePlut', 'DebonPQ', 

'DebonBA', 'Villaseca', 'MiddlemostPlut', 'QAPFPlut', 

'QANOR', 'Enrique', 'OConnorPlut', 

'Batchelor', 'LaurentSource', 'Harris', 

'Sylvester', 'LaYb', 'Meschede', 'Mullen', 'Norry', 

'Shervais', 'PearceEtAl', 'Pearce1982', 'Hollocher1', 

'Hollocher2', 'Ross','PearceNbThYb', 'PearceNbTiYb', 

'Cabanis', 'OhtaArai'.}

NB that this list can be shorter, reflecting the data available for plotting; 
it would also include any user-defined diagrams. 

If some analyses plot outside the limits, a warning is shown, and the 
diagram can be rescaled.
}

\value{
none
}

\examples{
    data(atacazo)
    accessVar("atacazo")
    
    plotDiagram("TAS",FALSE)
    
    print(.claslist())
    print(.tectlist())
    print(.userlist())
}

\keyword{hplot}
\keyword{internal}
\concept{Plot}
\concept{Classification}

\seealso{
\code{\link{classify}}, \code{\link{figaro}}, 
\code{\link{AFM}}, \code{\link{Miyashiro}}, 
\code{\link{PeceTaylor}}, \code{\link{Hastie}},  
\code{\link{NaAlK}}, \code{\link{Shand}},
\code{\link{TAS}}, \code{\link{Cox}},
\code{\link{TASMiddlemost}}, \code{\link{Jensen}}, 
\code{\link{Laroche}}, \code{\link{WinFloyd1}}, 
\code{\link{Pearce1996}}, \code{\link{WinFloyd2}}, 
\code{\link{QAPF}}, \code{\link{OConnor}},
\code{\link{DebonPQ}}, \code{\link{DebonBA}}, 
\code{\link{Villaseca}}, \code{\link{Middlemost}}, 
\code{\link{QANOR}}, \code{\link{Enrique}},
\code{\link{Batchelor}}, \code{\link{LaurentSource}},
\code{\link{Harris}}, \code{\link{Sylvester}},
\code{\link{LaYb}}, \code{\link{Meschede}},
\code{\link{Mullen}}, \code{\link{Norry}},
\code{\link{Shervais}}, \code{\link{PearceEtAl}},
\code{\link{Pearce1982}}, \code{\link{Hollocher1}},
\code{\link{Hollocher2}}, \code{\link{PearceNbThYb}},
\code{\link{PearceNbTiYb}}, \code{\link{Ross}},
\code{\link{OhtaArai}}, \code{\link{Cabanis}},
\code{\link{PearceDestructive1}}, \code{\link{PearceDestructive2}},
\code{\link{PearceDestructive3}}, \code{\link{Paulick}},
\code{\link{DebonKNaB}}, \code{\link{DebonQB}},
\code{\link{DebonBMgNo}}, \code{\link{DebonBQF}},
\code{\link{Grebennikov}}.
}

\author{
    Vojtch Erban, \email{erban@sopky.cz}
}
