\encoding{Windows-1250}
\name{spiderByGroupPatterns}
\title{Spider plot(s) - by group patterns}
\alias{spiderByGroupPatterns}

\description{
Plots a series of spiderplots, for each group one, in which individual patterns 
are shown.
}

\usage{
spiderByGroupPatterns(rock = WR, norm = NULL, bw = FALSE,
    ymin = 0, ymax = 0, xrotate = FALSE, offset = TRUE, centered = FALSE)
}

\arguments{
    \item{rock}{a numeric matrix; the whole-rock data from which will be filtered out those to be normalized.}
    \item{norm}{a character string specifying the model.}
    \item{bw}{logical; should be the plot black and white?}
    \item{ymin, ymax}{y range of the diagram.}
    \item{xrotate}{logical; shall be the element names on x axis rotated?}
    \item{offset}{logical; shall be the  names for odd and even elements shifted relative to each other?}
    \item{centered}{logical; shall be the element names on x axis plotted in between tick marks?}
}


\details{
Firstly, the normalization scheme is chosen and scaling for all the plots 
specified. Then, a series of spiderplots is plotted, for each group one, in 
which  patterns for individual samples are shown.
}

\value{
Returns a list '\code{results}' with the normalized values, and, in case of REE, some extra parameters.
 }

\examples{
    # Get the data ready
    data(blatna)
    accessVar("blatna")
    groupsByLabel("Suite")
    
    # Plot
    spiderByGroupPatterns(norm="Boynton",ymin=1,ymax=1000)

    spiderByGroupPatterns(norm="Boynton",bw=TRUE,ymin=1,ymax=1000,xrotate=TRUE,offset=FALSE)
}


\keyword{hplot}
\concept{Plot}
\concept{Spiderplot}
\concept{Grouping}
\concept{Menu: Plots}

\seealso{
For the syntax of the setup file with normalizing values and adding new 
normalization schemes see \code{\link{selectNorm}}. This function is based on 
\code{\link{spider}}.
}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}
