\encoding{Windows-1250}
\name{srnd}
\title{Recalculations of the Sr-Nd isotopic data}
\alias{srnd}
\alias{DMage}
\alias{DMGage}
\alias{DMLHage}
\alias{initial}
\alias{epsilon}

\section{Plugin}{SrNd.r}

\description{
    Age-corrects the Sr-Nd isotopic data to a given age; calculates initial 
    \eqn{\epsilon(Nd)} values and Nd model ages.
}

\usage{
    srnd(age = NULL)

    initial(age = NULL, x = WR, system = "Nd")

    epsilon(age, x = WR)

    DMage(x = WR)

    DMGage(x = WR)

    DMLHage(age = NULL, x = WR, RCC = 0.12)
}

\arguments{
  \item{age}{age in Ma.}
  \item{x}{numeric matrix with isotopic data to be recalculated.}
  \item{system}{character; which isotopic system: Sr or Nd?}
  \item{RCC}{numeric; the \eqn{^{147}Sm/^{144}Nd}{147Sm/144Nd} ratio of the intermediate 
    crustal reservoir for calculation of the two-stage Nd model ages.}
}

\details{
    Recalculates the Sr-Nd isotopic data and returns them in the numeric matrix 
    \code{init} with the following columns (DM = Depleted Mantle):

    \tabular{ll}{
    Age (Ma)\tab Age in Ma\cr
    87Sr/86Sri\tab Initial \eqn{^{87}Sr/^{86}Sr}{87Sr/86Sr} ratios\cr
    143Nd/144Ndi\tab Initial \eqn{^{143}Nd/^{144}Nd}{143Nd/144Nd}  ratios\cr
    EpsNdi\tab Initial \eqn{\epsilon(Nd)} values\cr
    TDM\tab Single-stage DM Nd model ages \emph{(Liew & Hofmann, 1988)}, function \code{DMage}\cr
    TDM.Gold\tab Single-stage DM Nd model ages \emph{(Goldstein et al., 1988)}, function \code{DMGage}\cr
    TDM.2stg\tab Two-stage DM Nd model ages \emph{(Liew & Hofmann, 1988)}, function \code{DMLHage}\cr
    }
    
    If the parameter \code{age} in call to the main function \code{srnd()} is empty, 
    and no column named \code{Age} is found in the dataset, 
    the user is prompted to enter a value. 
    For other functions, the argument \code{age} is empty, it is taken from the 
    value assigned upon loading the dataset. 
}

\value{
For \code{srnd()}:
    \item{init}{numeric matrix with the results}
    \item{age}{numeric vector with the ages used in calculations for each sample} 
For all functions:
    \item{results}{numeric matrix, or vector, with the results} 
}

\references{
    Goldstein SL, O'Nions RK & Hamilton PJ (1984) A Sm-Nd isotopic study of 
    atmospheric dusts and particulates from major river systems. Earth Planet Sci 
    Lett 70: 221-236
    \doi{10.1016/0012-821X(84)90007-4}

    Liew TC & Hofmann AW (1988) Precambrian crustal components, plutonic 
    associations, plate environment of the Hercynian Fold Belt of Central Europe: 
    indications from a Nd and Sr isotopic study. Contrib Mineral Petrol 98: 129-138
    \doi{10.1007/BF00402106}
}

\seealso{
    \link{elemIso}, \link{reciprocalIso}, \link{ageEps},  
    
    \link{epsEps}, \link{isochron},  
    
    \link{boxplotIso}, \link{stripplotIso}, 
    
    \link{addResultsIso}, \link{saveResultsIso}
}

\examples{
    data(blatna_iso)
    accessVar("blatna_iso")
    
    srnd() # Using the age information from the file; 
    # This is done automatically upon loading a new data file.
    
    srnd(500)
    
    initial(346,system="Sr")

    out<-cbind(epsilon(0),epsilon(346))
    colnames(out)<-c(0,346)
    print(out)
    
    DMage()

    DMGage()

    DMLHage()
}

\keyword{manip}
\concept{Calculation}
\concept{Isotopic}
\concept{Menu: Plugins}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}
