\encoding{Windows-1250}
\name{statsByGroup}
\title{Statistics by groups}
\alias{statsByGroup}

\description{
Calculates simple descriptive statistics for individual columns of the given 
data matrix; optionally this can be done for each of the groups separately. 
}

\usage{
    statsByGroup(dataset = WR, groups = NULL)
}

\arguments{
    \item{dataset}{numeric data matrix.}
    \item{groups}{a vector, in which is specified, for each sample, a group it belongs to.}
}

\details{
    The function returns a list containing the calculated statistical parameters 
    respecting the current grouping. The statistical summary involves number of 
    observations, missing values, mean, standard deviation, minimum, 25\% quartile, 
    median (= 50\% quartile), 75\% quartile and maximum. This is a core function 
    invoked both by \code{\link{summarySingle}} and \code{\link{summarySingleByGroup}}.
}

\examples{
    data(blatna)
    accessVar("blatna")
    groupsByLabel("Suite")
    
    statsByGroup()

    statsByGroup(WR[,LILE])
}


\value{
    \item{results}{a matrix with the means and single standard deviations of both variables
    for each of the individual groups}
}

\seealso{
\itemize{
\code{\link{summarySingle}}

\code{\link{statistics}}

\code{\link{summaryAll}}

\code{\link{summaryByGroup}}
}
}

\keyword{univar}
\concept{Calculation}
\concept{Grouping}
\concept{Menu: Calculations: Statistics}
\concept{Statistics}

\author{Vojtch Janouek, \email{vojtech.janousek@geology.cz}}
